import React, { useState, useEffect } from 'react';
import { Form, Icon, Input, Button, DatePicker, InputNumber, Radio } from 'antd';
import Styles from './style.less';

function CreatActivity(props) {
    const { getFieldDecorator } = props.form;
    const { RangePicker } = DatePicker;

    const [tab, setTab] = useState('0')
    const formItemLayout = {
        labelCol: {
            xs: { span: 24 },
            sm: { span: 5 },
        },
        wrapperCol: {
            xs: { span: 24 },
            sm: { span: 16 },
        },
    };


    function handleSubmit(e) {
        e.preventDefault();
        props.form.validateFieldsAndScroll((err, values) => {
            if (!err) {
                props.onNext()
            }
        });
    }

    return (
        <>
            <Form {...formItemLayout} onSubmit={handleSubmit}>
                <p className={Styles.title}>基本信息</p>
                <Form.Item label="活动名称" >
                    {getFieldDecorator('activityName', {
                        rules: [{ required: true, message: '请输入活动名称' }],
                    })(<Input />)}
                </Form.Item>
                <Form.Item label="活动时间">
                    {getFieldDecorator('activityTime', {
                        rules: [
                            {
                                required: true,
                                message: '请选择活动时间',
                            },
                        ],
                    })(<RangePicker format="YYYY-MM-DD HH:mm" />)}
                </Form.Item>

                <Form.Item label="参与身份" >
                    {getFieldDecorator('role', {
                        initialValue: 1,
                    })(
                        <Radio.Group>
                            <Radio value={1}>所有用户</Radio>
                            <Radio value={2}>新用户（未注册过手机号）</Radio>
                        </Radio.Group>,
                    )}
                </Form.Item>

                <Form.Item label="活动类型" >
                    {getFieldDecorator('activityType', {
                        initialValue: 1,
                    })(
                        <Radio.Group>
                            <Radio value={1}>无线抽奖</Radio>
                            <Radio value={2}>积分抽奖，消耗 {getFieldDecorator('integral')(<InputNumber min={1} />)} 积分</Radio>
                        </Radio.Group>,
                    )}
                </Form.Item>

                <Form.Item label="参与次数" >
                    {getFieldDecorator('times', {
                        initialValue: 1,
                    })(
                        <Radio.Group>
                            <Radio value={1}>
                                一天N次
                                <div style={{ marginTop: '8px' }}>每人每天抽 {getFieldDecorator('times1')(<InputNumber min={1} />)} 次</div>
                                <div>每天分享额外抽 {getFieldDecorator('times2')(<InputNumber min={1} />)} 次</div>
                            </Radio>
                            <Radio value={2}>
                                一人N次
                                        <div style={{ marginTop: '8px' }}>每人一共可抽 {getFieldDecorator('times3')(<InputNumber min={1} />)} 次</div>
                                <div>每人分享额外抽 {getFieldDecorator('times4')(<InputNumber min={1} />)} 次</div>
                            </Radio>
                        </Radio.Group>,
                    )}
                </Form.Item>



                <Form.Item style={{ width: '500px', margin: 'auto', display: 'flex', justifyContent: 'space-between' }}>
                    <Button onClick={() => router.go(-1)} style={{ margin: '0 20px' }}>
                        取消
                    </Button>

                    <Button type="primary" htmlType="submit">
                        下一步
                    </Button>
                </Form.Item>
            </Form>
        </>
    )
}

const WrappedCreatActivityForm = Form.create({ name: 'CreatActivity' })(CreatActivity);

export default WrappedCreatActivityForm
