import React, { useState, useEffect } from 'react';
import { Form, Icon, Input, Button, Table, InputNumber, Radio } from 'antd';
import Styles from './style.less';

function Award(props) {
    const { getFieldDecorator } = props.form;

    const formItemLayout = {
        labelCol: {
            xs: { span: 24 },
            sm: { span: 5 },
        },
        wrapperCol: {
            xs: { span: 24 },
            sm: { span: 16 },
        },
    };
    const list = [
        {
            name: '特等奖',
            award: '华为P30pro',
            img: 'http://img1.imgtn.bdimg.com/it/u=3784469630,654971&fm=26&gp=0.jpg',
            num: '2',
            percent: '5%',
            provide: '',
            index: '1'
        },
        {
            name: '一等奖',
            award: '500元苏果卡',
            img: 'https://ss0.bdstatic.com/70cFuHSh_Q1YnxGkpoWK1HF6hhy/it/u=637033601,3111670601&fm=26&gp=0.jpg',
            num: '50',
            percent: '20%',
            provide: '',
            index: '2'
        },
        {
            name: '二等奖',
            award: '300元苏果卡',
            img: 'https://ss2.bdstatic.com/70cFvnSh_Q1YnxGkpoWK1HF6hhy/it/u=1997215264,2437398566&fm=26&gp=0.jpg',
            num: '20',
            percent: '30%',
            provide: '',
            index: '3'
        },
        {
            name: '三等奖',
            award: '100积分',
            img: 'https://timgsa.baidu.com/timg?image&quality=80&size=b9999_10000&sec=1591957675722&di=ff6e441952a79e88e7a78123bf185bc6&imgtype=0&src=http%3A%2F%2F588ku.izihun.com%2Felement_origin_min_pic%2F18%2F08%2F22%2F59423ed3bcf4af7517454958f989b912.jpg%2521%2Ffw%2F820%2Fquality%2F100%2Funsharp%2Ftrue%2Fcompress%2Ftrue%2Fformat%2Fjpeg',
            num: '50',
            percent: '50%',
            provide: '',
            index: '4'
        },

    ]


    const columns = [
        {
            title: '名称',
            dataIndex: 'name',
            key: 'name',
            align: 'center',
        },
        {
            title: '奖品',
            dataIndex: 'award',
            key: 'award',
            align: 'center',
        },
        {
            title: '图片',
            dataIndex: 'img',
            key: 'img',
            align: 'center',
            render: (img) => <img style={{ width: '40px', height: '40px' }} src={img}></img>
        },
        {
            title: '数量',
            dataIndex: 'num',
            key: 'num',
            align: 'center',
        },
        {
            title: '中奖概率',
            dataIndex: 'percent',
            key: 'percent',
            align: 'center',
        },
        {
            title: '已发放',
            dataIndex: 'provide',
            key: 'provide',
            align: 'center',
        },
        {
            title: '操作',
            dataIndex: 'handle',
            key: 'handle',
            align: 'center',
            render: () => <>
                <span style={{ color: '#FF4A4A', marginRight: '6px' }}>编辑</span>
                <span style={{ color: '#FF4A4A' }}>删除</span>
            </>
        },
    ];

    function handleSubmit(e) {
        e.preventDefault();
        props.form.validateFieldsAndScroll((err, values) => {
            if (!err) {
                props.onNext()
            }
        });
    }


    return (
        <>
            <Form {...formItemLayout} onSubmit={handleSubmit}>
                <p className={Styles.title}>奖品设置</p>
                <p className={Styles.blue}>添加奖品</p>
                <Table className={Styles.table} bordered dataSource={list} columns={columns} pagination={false} rowKey={(x => x.index)} />
                <p className={Styles.title} style={{ marginTop: '20px' }}>未中奖设置</p>
                <Form.Item label="名称" >
                    {getFieldDecorator('name', {
                        rules: [{ required: true, message: '请输入名称' }],
                    })(<Input placeholder='请输入名称' />)}
                </Form.Item>
                <Form.Item label="图片" >
                    <img style={{ width: '120px', height: '120px', marginRight: '10px' }} src="https://ss1.bdstatic.com/70cFuXSh_Q1YnxGkpoWK1HF6hhy/it/u=2907552255,1679967258&fm=26&gp=0.jpg" alt="" />
                    <span className={Styles.blue}>修改</span>
                </Form.Item>
                <Form.Item label="提示语" >
                    {getFieldDecorator('tip')(<Input placeholder='请输入提示语' />)}
                </Form.Item>
                <Form.Item label="提示跳转" >
                    {getFieldDecorator('role', {
                        initialValue: 1,
                    })(
                        <Radio.Group>
                            <Radio value={1}>无跳转</Radio>
                            <Radio value={2}>有跳转 <span className={Styles.blue}>选择跳转界面</span> </Radio>
                        </Radio.Group>,
                    )}
                </Form.Item>
                <p className={Styles.title} style={{ marginTop: '20px' }}>参与送积分</p>

                <Form.Item >
                    参与送 {getFieldDecorator('jifen')(<InputNumber min={1} />)} 积分
                </Form.Item>
                <Form.Item>
                    {getFieldDecorator('noaward')(
                        <Radio.Group>
                            <Radio value={1}>仅送给未中奖用户</Radio>
                        </Radio.Group>,

                    )}
                </Form.Item>

                <Form.Item style={{ width: '500px', margin: 'auto', display: 'flex', justifyContent: 'space-between' }}>
                    <Button onClick={() => props.onPre()} style={{ margin: '0 20px' }}>
                        上一步
                    </Button>
                    <Button type="primary" htmlType="submit">
                        下一步
                    </Button>
                </Form.Item>
            </Form>
        </>
    )
}

const WrappedAwardForm = Form.create({ name: 'Award' })(Award);

export default WrappedAwardForm
