import React, { useState, useEffect } from 'react';
import { Row, Col, Card, Modal, Button, message } from 'antd';
import router from 'umi/router';
import one from '../../assets/miniapp/one.png'
import two from '../../assets/miniapp/two.png'
import three from '../../assets/miniapp/three.png'
import four from '../../assets/miniapp/four.png'
import preview from '../../assets/miniapp/preview.png'
import code from '../../assets/miniapp/code.png'
import prototype1 from '../../assets/miniapp/prototype1.png'
import prototype2 from '../../assets/miniapp/prototype2.png'
import prototype3 from '../../assets/miniapp/prototype3.png'
import prototype4 from '../../assets/miniapp/prototype4.png'
import use from '../../assets/miniapp/use.png'

const MiniAppTheme = props => {
    const [active, setActive] = useState({})
    const [visible, setVisible] = useState(false)

    const list = [
        {
            title: '橙蕉小程序驼色调',
            img: one,
            index: '1',
            used: true,
            previewImg: prototype1,
        },
        {
            title: '橙蕉小程序橙色调',
            img: two,
            index: '2',
            previewImg: prototype2,
        },
        {
            title: '橙蕉小程序蓝色调',
            img: three,
            index: '3',
            previewImg: prototype3,
        },
        {
            title: '橙蕉小程序深色调',
            img: four,
            index: '4',
            previewImg: prototype4,
        },
    ]

    return <>
        <Modal
            visible={visible}
            title="主题模板使用"
            width='1200px'
            onCancel={() => setVisible(false)}
            footer={[
                <div style={{ textAlign: 'center' }}>
                    <Button type="primary" style={{ margin: '0 20px' }} onClick={() => message.info('操作成功！') && setVisible(false)}>
                        使用
                </Button>
                    <Button onClick={() => setVisible(false)}>
                        取消
                </Button>
                </div>
            ]}
        >
            <div style={{ display: 'flex', alignItems: 'center', justifyContent: 'center' }}>
                <div style={{ textAlign: 'center', marginRight: '50px' }}>
                    <img style={{ width: '240px' }} src={active.previewImg} />
                    <p style={{ fontWeight: '600', marginTop: '10px' }}>{active.title}</p>
                </div>
                <div style={{ textAlign: 'center' }}>
                    <img style={{ width: '88px' }} src={code} />
                    <p style={{ margin: '6px 0 10px 0' }}>扫描二维码预览</p>
                    <p >预览效果仅供参考，请以实际投放标准为准</p>
                </div>
            </div>
        </Modal>

        <Row style={{ width: '100%' }}>
            {
                list.map((item, index) => (
                    <Col key={index} span={6}>
                        <Card
                            hoverable
                            style={{ minWidth: '330px', borderRadius: '12px', margin: '10px', boxShadow: '0px 0px 16px 2px rgba(0,0,0,0.12)' }}
                        >
                            <div style={{ padding: '20px' }} onMouseEnter={() => setActive(item)}>
                                <img style={{ width: '100%', height: '100%' }} src={item.img}></img>
                                {
                                    active.index === item.index && <div style={{ position: 'absolute', top: '20px', right: '14px' }}>
                                        <img onClick={() => setVisible(true)} style={{ padding: '8px', backgroundColor: '#fff', marginRight: '20px', borderRadius: '6px', }} src={preview} />
                                        <img style={{ width: '90px', height: '40px' }} onClick={() => message.info('操作成功！')} src={use} />
                                    </div>
                                }

                                {
                                    item.used && <div style={{
                                        display: 'flex',
                                        alignItems: 'center',
                                        width: '90%',
                                        justifyContent: 'space-between',
                                        position: 'absolute',
                                        padding: '10px',
                                        backgroundColor: '#fff',
                                        bottom: '0'
                                    }}>
                                        <p style={{ fontSize: '0.1rem', fontWeight: '600', marginBottom: '0px' }}>{item.title}</p>
                                        <p style={{ color: '#FF7E48', marginBottom: '0px' }}>使用中</p>
                                    </div>
                                }
                            </div>

                        </Card>
                    </Col>
                ))
            }
        </Row>


    </>
}

export default MiniAppTheme
